# Bach mouse mammary gland (10X Genomics)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the @bach2017differentiation 10X Genomics dataset,
from which we will consider a single sample of epithelial cells from the mouse mammary gland during gestation.

## Data loading


```r
library(scRNAseq)
sce.mam <- BachMammaryData(samples="G_1")
```


```r
library(scater)
rownames(sce.mam) <- uniquifyFeatureNames(
    rowData(sce.mam)$Ensembl, rowData(sce.mam)$Symbol)

library(AnnotationHub)
ens.mm.v97 <- AnnotationHub()[["AH73905"]]
rowData(sce.mam)$SEQNAME <- mapIds(ens.mm.v97, keys=rowData(sce.mam)$Ensembl,
    keytype="GENEID", column="SEQNAME")
```

## Quality control


```r
unfiltered <- sce.mam
```


```r
is.mito <- rowData(sce.mam)$SEQNAME == "MT"
stats <- perCellQCMetrics(sce.mam, subsets=list(Mito=which(is.mito)))
qc <- quickPerCellQC(stats, percent_subsets="subsets_Mito_percent")
sce.mam <- sce.mam[,!qc$discard]
```


```r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, y="sum", colour_by="discard") + 
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, y="detected", colour_by="discard") + 
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, y="subsets_Mito_percent", 
        colour_by="discard") + ggtitle("Mito percent"),
    ncol=2
)
```

<div class="figure">
<img src="bach-mammary_files/figure-html/unref-bach-qc-dist-1.png" alt="Distribution of each QC metric across cells in the Bach mammary gland dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-bach-qc-dist)Distribution of each QC metric across cells in the Bach mammary gland dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>


```r
plotColData(unfiltered, x="sum", y="subsets_Mito_percent", 
    colour_by="discard") + scale_x_log10()
```

<div class="figure">
<img src="bach-mammary_files/figure-html/unref-bach-qc-comp-1.png" alt="Percentage of mitochondrial reads in each cell in the Bach mammary gland dataset compared to its total count. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-bach-qc-comp)Percentage of mitochondrial reads in each cell in the Bach mammary gland dataset compared to its total count. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>


```r
colSums(as.matrix(qc))
```

```
##              low_lib_size            low_n_features high_subsets_Mito_percent 
##                         0                         0                       143 
##                   discard 
##                       143
```

## Normalization 


```r
library(scran)
set.seed(101000110)
clusters <- quickCluster(sce.mam)
sce.mam <- computeSumFactors(sce.mam, clusters=clusters)
sce.mam <- logNormCounts(sce.mam)
```


```r
summary(sizeFactors(sce.mam))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.271   0.522   0.758   1.000   1.204  10.958
```


```r
plot(librarySizeFactors(sce.mam), sizeFactors(sce.mam), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="bach-mammary_files/figure-html/unref-bach-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Bach mammary gland dataset." width="672" />
<p class="caption">(\#fig:unref-bach-norm)Relationship between the library size factors and the deconvolution size factors in the Bach mammary gland dataset.</p>
</div>

## Variance modelling

We use a Poisson-based technical trend to capture more genuine biological variation in the biological component.


```r
set.seed(00010101)
dec.mam <- modelGeneVarByPoisson(sce.mam)
top.mam <- getTopHVGs(dec.mam, prop=0.1)
```


```r
plot(dec.mam$mean, dec.mam$total, pch=16, cex=0.5,
    xlab="Mean of log-expression", ylab="Variance of log-expression")
curfit <- metadata(dec.mam)
curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
```

<div class="figure">
<img src="bach-mammary_files/figure-html/unref-bach-var-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Bach mammary gland dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to simulated Poisson counts." width="672" />
<p class="caption">(\#fig:unref-bach-var)Per-gene variance as a function of the mean for the log-expression values in the Bach mammary gland dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to simulated Poisson counts.</p>
</div>

## Dimensionality reduction


```r
library(BiocSingular)
set.seed(101010011)
sce.mam <- denoisePCA(sce.mam, technical=dec.mam, subset.row=top.mam)
sce.mam <- runTSNE(sce.mam, dimred="PCA")
```


```r
ncol(reducedDim(sce.mam, "PCA"))
```

```
## [1] 15
```

## Clustering 

We use a higher `k` to obtain coarser clusters (for use in `doubletCluster()` later).


```r
snn.gr <- buildSNNGraph(sce.mam, use.dimred="PCA", k=25)
colLabels(sce.mam) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


```r
table(colLabels(sce.mam))
```

```
## 
##   1   2   3   4   5   6   7   8   9  10 
## 550 799 716 452  24  84  52  39  32  24
```


```r
plotTSNE(sce.mam, colour_by="label")
```

<div class="figure">
<img src="bach-mammary_files/figure-html/unref-bach-tsne-1.png" alt="Obligatory $t$-SNE plot of the Bach mammary gland dataset, where each point represents a cell and is colored according to the assigned cluster." width="672" />
<p class="caption">(\#fig:unref-bach-tsne)Obligatory $t$-SNE plot of the Bach mammary gland dataset, where each point represents a cell and is colored according to the assigned cluster.</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.2.1 (2022-06-23)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.5 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.15-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.15-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] BiocSingular_1.12.0         scran_1.24.1               
 [3] AnnotationHub_3.4.0         BiocFileCache_2.4.0        
 [5] dbplyr_2.2.1                scater_1.24.0              
 [7] ggplot2_3.3.6               scuttle_1.6.3              
 [9] ensembldb_2.20.2            AnnotationFilter_1.20.0    
[11] GenomicFeatures_1.48.4      AnnotationDbi_1.58.0       
[13] scRNAseq_2.10.0             SingleCellExperiment_1.18.1
[15] SummarizedExperiment_1.26.1 Biobase_2.56.0             
[17] GenomicRanges_1.48.0        GenomeInfoDb_1.32.4        
[19] IRanges_2.30.1              S4Vectors_0.34.0           
[21] BiocGenerics_0.42.0         MatrixGenerics_1.8.1       
[23] matrixStats_0.62.0          BiocStyle_2.24.0           
[25] rebook_1.6.0               

loaded via a namespace (and not attached):
  [1] igraph_1.3.5                  lazyeval_0.2.2               
  [3] BiocParallel_1.30.4           digest_0.6.29                
  [5] htmltools_0.5.3               viridis_0.6.2                
  [7] fansi_1.0.3                   magrittr_2.0.3               
  [9] memoise_2.0.1                 ScaledMatrix_1.4.1           
 [11] cluster_2.1.4                 limma_3.52.4                 
 [13] Biostrings_2.64.1             prettyunits_1.1.1            
 [15] colorspace_2.0-3              blob_1.2.3                   
 [17] rappdirs_0.3.3                ggrepel_0.9.1                
 [19] xfun_0.33                     dplyr_1.0.10                 
 [21] crayon_1.5.2                  RCurl_1.98-1.9               
 [23] jsonlite_1.8.2                graph_1.74.0                 
 [25] glue_1.6.2                    gtable_0.3.1                 
 [27] zlibbioc_1.42.0               XVector_0.36.0               
 [29] DelayedArray_0.22.0           scales_1.2.1                 
 [31] edgeR_3.38.4                  DBI_1.1.3                    
 [33] Rcpp_1.0.9                    viridisLite_0.4.1            
 [35] xtable_1.8-4                  progress_1.2.2               
 [37] dqrng_0.3.0                   bit_4.0.4                    
 [39] rsvd_1.0.5                    metapod_1.4.0                
 [41] httr_1.4.4                    dir.expiry_1.4.0             
 [43] ellipsis_0.3.2                pkgconfig_2.0.3              
 [45] XML_3.99-0.11                 farver_2.1.1                 
 [47] CodeDepends_0.6.5             sass_0.4.2                   
 [49] locfit_1.5-9.6                utf8_1.2.2                   
 [51] labeling_0.4.2                tidyselect_1.2.0             
 [53] rlang_1.0.6                   later_1.3.0                  
 [55] munsell_0.5.0                 BiocVersion_3.15.2           
 [57] tools_4.2.1                   cachem_1.0.6                 
 [59] cli_3.4.1                     generics_0.1.3               
 [61] RSQLite_2.2.18                ExperimentHub_2.4.0          
 [63] evaluate_0.17                 stringr_1.4.1                
 [65] fastmap_1.1.0                 yaml_2.3.5                   
 [67] knitr_1.40                    bit64_4.0.5                  
 [69] purrr_0.3.5                   KEGGREST_1.36.3              
 [71] sparseMatrixStats_1.8.0       mime_0.12                    
 [73] xml2_1.3.3                    biomaRt_2.52.0               
 [75] compiler_4.2.1                beeswarm_0.4.0               
 [77] filelock_1.0.2                curl_4.3.3                   
 [79] png_0.1-7                     interactiveDisplayBase_1.34.0
 [81] statmod_1.4.37                tibble_3.1.8                 
 [83] bslib_0.4.0                   stringi_1.7.8                
 [85] highr_0.9                     bluster_1.6.0                
 [87] lattice_0.20-45               ProtGenerics_1.28.0          
 [89] Matrix_1.5-1                  vctrs_0.4.2                  
 [91] pillar_1.8.1                  lifecycle_1.0.3              
 [93] BiocManager_1.30.18           jquerylib_0.1.4              
 [95] BiocNeighbors_1.14.0          cowplot_1.1.1                
 [97] bitops_1.0-7                  irlba_2.3.5.1                
 [99] httpuv_1.6.6                  rtracklayer_1.56.1           
[101] R6_2.5.1                      BiocIO_1.6.0                 
[103] bookdown_0.29                 promises_1.2.0.1             
[105] gridExtra_2.3                 vipor_0.4.5                  
[107] codetools_0.2-18              assertthat_0.2.1             
[109] rjson_0.2.21                  withr_2.5.0                  
[111] GenomicAlignments_1.32.1      Rsamtools_2.12.0             
[113] GenomeInfoDbData_1.2.8        parallel_4.2.1               
[115] hms_1.1.2                     grid_4.2.1                   
[117] beachmat_2.12.0               rmarkdown_2.17               
[119] DelayedMatrixStats_1.18.2     Rtsne_0.16                   
[121] shiny_1.7.2                   ggbeeswarm_0.6.0             
[123] restfulr_0.0.15              
```
</div>
