# Grun human pancreas (CEL-seq2) 

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This workflow performs an analysis of the @grun2016denovo CEL-seq2 dataset consisting of human pancreas cells from various donors.

## Data loading


```r
library(scRNAseq)
sce.grun <- GrunPancreasData()
```

We convert to Ensembl identifiers, and we remove duplicated genes or genes without Ensembl IDs.


```r
library(org.Hs.eg.db)
gene.ids <- mapIds(org.Hs.eg.db, keys=rowData(sce.grun)$symbol,
    keytype="SYMBOL", column="ENSEMBL")

keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.grun <- sce.grun[keep,]
rownames(sce.grun) <- gene.ids[keep]
```

## Quality control


```r
unfiltered <- sce.grun
```

This dataset lacks mitochondrial genes so we will do without them for quality control.
We compute the median and MAD while blocking on the donor;
for donors where the assumption of a majority of high-quality cells seems to be violated (Figure \@ref(fig:unref-grun-qc-dist)),
we compute an appropriate threshold using the other donors as specified in the `subset=` argument.


```r
library(scater)
stats <- perCellQCMetrics(sce.grun)

qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.grun$donor,
    subset=sce.grun$donor %in% c("D17", "D7", "D2"))

sce.grun <- sce.grun[,!qc$discard]
```


```r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor of the Grun pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-grun-qc-dist)Distribution of each QC metric across cells from each donor of the Grun pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>


```r
colSums(as.matrix(qc), na.rm=TRUE)
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       450                       510                       606 
##                   discard 
##                       665
```

## Normalization 


```r
library(scran)
set.seed(1000) # for irlba. 
clusters <- quickCluster(sce.grun)
sce.grun <- computeSumFactors(sce.grun, clusters=clusters)
sce.grun <- logNormCounts(sce.grun)
```


```r
summary(sizeFactors(sce.grun))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.098   0.506   0.792   1.000   1.223  12.053
```


```r
plot(librarySizeFactors(sce.grun), sizeFactors(sce.grun), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Grun pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-grun-norm)Relationship between the library size factors and the deconvolution size factors in the Grun pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


```r
block <- paste0(sce.grun$sample, "_", sce.grun$donor)
dec.grun <- modelGeneVarWithSpikes(sce.grun, spikes="ERCC", block=block)
top.grun <- getTopHVGs(dec.grun, prop=0.1)
```

We examine the number of cells in each level of the blocking factor.


```r
table(block)
```

```
## block
##                  CD13+ sorted cells_D17       CD24+ CD44+ live sorted cells_D17 
##                                      86                                      87 
##                  CD63+ sorted cells_D10                TGFBR3+ sorted cells_D17 
##                                      41                                      90 
## exocrine fraction, live sorted cells_D2 exocrine fraction, live sorted cells_D3 
##                                      82                                       7 
##        live sorted cells, library 1_D10        live sorted cells, library 1_D17 
##                                      33                                      88 
##         live sorted cells, library 1_D3         live sorted cells, library 1_D7 
##                                      24                                      85 
##        live sorted cells, library 2_D10        live sorted cells, library 2_D17 
##                                      35                                      83 
##         live sorted cells, library 2_D3         live sorted cells, library 2_D7 
##                                      27                                      84 
##         live sorted cells, library 3_D3         live sorted cells, library 3_D7 
##                                      16                                      83 
##         live sorted cells, library 4_D3         live sorted cells, library 4_D7 
##                                      29                                      83
```


```r
par(mfrow=c(6,3))
blocked.stats <- dec.grun$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-416b-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Grun pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-416b-variance)Per-gene variance as a function of the mean for the log-expression values in the Grun pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


```r
library(batchelor)
set.seed(1001010)
merged.grun <- fastMNN(sce.grun, subset.row=top.grun, batch=sce.grun$donor)
```


```r
metadata(merged.grun)$merge.info$lost.var
```

```
##           D10      D17       D2      D3      D7
## [1,] 0.030204 0.030289 0.000000 0.00000 0.00000
## [2,] 0.006802 0.010587 0.036950 0.00000 0.00000
## [3,] 0.003840 0.005669 0.007492 0.04999 0.00000
## [4,] 0.012435 0.015092 0.014262 0.01323 0.05275
```

## Dimensionality reduction


```r
set.seed(100111)
merged.grun <- runTSNE(merged.grun, dimred="corrected")
```

## Clustering


```r
snn.gr <- buildSNNGraph(merged.grun, use.dimred="corrected")
colLabels(merged.grun) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


```r
table(Cluster=colLabels(merged.grun), Donor=merged.grun$batch)
```

```
##        Donor
## Cluster D10 D17  D2  D3  D7
##       1  17  74   3   2  77
##       2   6  12   5   7   6
##       3  12 128   0   0  62
##       4  28 107  43  13 118
##       5  32  70  31  80  28
##       6   5  13   0   0  10
##       7   4  13   0   0   1
##       8   5  17   0   1  33
```


```r
gridExtra::grid.arrange(
    plotTSNE(merged.grun, colour_by="label"),
    plotTSNE(merged.grun, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-tsne-1.png" alt="Obligatory $t$-SNE plots of the Grun pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-grun-tsne)Obligatory $t$-SNE plots of the Grun pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.2.1 (2022-06-23)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.5 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.15-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.15-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] batchelor_1.12.3            scran_1.24.1               
 [3] scater_1.24.0               ggplot2_3.3.6              
 [5] scuttle_1.6.3               org.Hs.eg.db_3.15.0        
 [7] AnnotationDbi_1.58.0        scRNAseq_2.10.0            
 [9] SingleCellExperiment_1.18.1 SummarizedExperiment_1.26.1
[11] Biobase_2.56.0              GenomicRanges_1.48.0       
[13] GenomeInfoDb_1.32.4         IRanges_2.30.1             
[15] S4Vectors_0.34.0            BiocGenerics_0.42.0        
[17] MatrixGenerics_1.8.1        matrixStats_0.62.0         
[19] BiocStyle_2.24.0            rebook_1.6.0               

loaded via a namespace (and not attached):
  [1] AnnotationHub_3.4.0           BiocFileCache_2.4.0          
  [3] igraph_1.3.5                  lazyeval_0.2.2               
  [5] BiocParallel_1.30.4           digest_0.6.29                
  [7] ensembldb_2.20.2              htmltools_0.5.3              
  [9] viridis_0.6.2                 fansi_1.0.3                  
 [11] magrittr_2.0.3                memoise_2.0.1                
 [13] ScaledMatrix_1.4.1            cluster_2.1.4                
 [15] limma_3.52.4                  Biostrings_2.64.1            
 [17] prettyunits_1.1.1             colorspace_2.0-3             
 [19] blob_1.2.3                    rappdirs_0.3.3               
 [21] ggrepel_0.9.1                 xfun_0.33                    
 [23] dplyr_1.0.10                  crayon_1.5.2                 
 [25] RCurl_1.98-1.9                jsonlite_1.8.2               
 [27] graph_1.74.0                  glue_1.6.2                   
 [29] gtable_0.3.1                  zlibbioc_1.42.0              
 [31] XVector_0.36.0                DelayedArray_0.22.0          
 [33] BiocSingular_1.12.0           scales_1.2.1                 
 [35] edgeR_3.38.4                  DBI_1.1.3                    
 [37] Rcpp_1.0.9                    viridisLite_0.4.1            
 [39] xtable_1.8-4                  progress_1.2.2               
 [41] dqrng_0.3.0                   bit_4.0.4                    
 [43] rsvd_1.0.5                    ResidualMatrix_1.6.1         
 [45] metapod_1.4.0                 httr_1.4.4                   
 [47] dir.expiry_1.4.0              ellipsis_0.3.2               
 [49] pkgconfig_2.0.3               XML_3.99-0.11                
 [51] farver_2.1.1                  CodeDepends_0.6.5            
 [53] sass_0.4.2                    dbplyr_2.2.1                 
 [55] locfit_1.5-9.6                utf8_1.2.2                   
 [57] labeling_0.4.2                tidyselect_1.2.0             
 [59] rlang_1.0.6                   later_1.3.0                  
 [61] munsell_0.5.0                 BiocVersion_3.15.2           
 [63] tools_4.2.1                   cachem_1.0.6                 
 [65] cli_3.4.1                     generics_0.1.3               
 [67] RSQLite_2.2.18                ExperimentHub_2.4.0          
 [69] evaluate_0.17                 stringr_1.4.1                
 [71] fastmap_1.1.0                 yaml_2.3.5                   
 [73] knitr_1.40                    bit64_4.0.5                  
 [75] purrr_0.3.5                   KEGGREST_1.36.3              
 [77] AnnotationFilter_1.20.0       sparseMatrixStats_1.8.0      
 [79] mime_0.12                     xml2_1.3.3                   
 [81] biomaRt_2.52.0                compiler_4.2.1               
 [83] beeswarm_0.4.0                filelock_1.0.2               
 [85] curl_4.3.3                    png_0.1-7                    
 [87] interactiveDisplayBase_1.34.0 statmod_1.4.37               
 [89] tibble_3.1.8                  bslib_0.4.0                  
 [91] stringi_1.7.8                 highr_0.9                    
 [93] GenomicFeatures_1.48.4        bluster_1.6.0                
 [95] lattice_0.20-45               ProtGenerics_1.28.0          
 [97] Matrix_1.5-1                  vctrs_0.4.2                  
 [99] pillar_1.8.1                  lifecycle_1.0.3              
[101] BiocManager_1.30.18           jquerylib_0.1.4              
[103] BiocNeighbors_1.14.0          cowplot_1.1.1                
[105] bitops_1.0-7                  irlba_2.3.5.1                
[107] httpuv_1.6.6                  rtracklayer_1.56.1           
[109] R6_2.5.1                      BiocIO_1.6.0                 
[111] bookdown_0.29                 promises_1.2.0.1             
[113] gridExtra_2.3                 vipor_0.4.5                  
[115] codetools_0.2-18              assertthat_0.2.1             
[117] rjson_0.2.21                  withr_2.5.0                  
[119] GenomicAlignments_1.32.1      Rsamtools_2.12.0             
[121] GenomeInfoDbData_1.2.8        parallel_4.2.1               
[123] hms_1.1.2                     grid_4.2.1                   
[125] beachmat_2.12.0               rmarkdown_2.17               
[127] DelayedMatrixStats_1.18.2     Rtsne_0.16                   
[129] shiny_1.7.2                   ggbeeswarm_0.6.0             
[131] restfulr_0.0.15              
```
</div>
